@@ -166,11 +166,11 @@ class EnumMeta(type):
 
         # create our new Enum type
         enum_class = super(EnumMeta, metacls).__new__(metacls, cls, bases, classdict)
-        enum_class._member_names = []               # names in random order
-        enum_class._member_map = {}                 # name->value map
+        enum_class._member_names_ = []               # names in random order
+        enum_class._member_map_ = {}                 # name->value map
 
         # Reverse value->name map for hashable values.
-        enum_class._value2member_map = {}
+        enum_class._value2member_map_ = {}
 
         # check for a __getnewargs__, and if not present sabotage
         # pickling, since it won't work anyway
@@ -195,40 +195,41 @@ class EnumMeta(type):
                 args = (args, )     # wrap it one more time
             if not use_args or not args:
                 enum_member = __new__(enum_class)
-                if not hasattr(enum_member, '_value'):
-                    enum_member._value = value
+                original_value = value
             else:
                 enum_member = __new__(enum_class, *args)
-                if not hasattr(enum_member, '_value'):
-                    enum_member._value = member_type(*args)
-            enum_member._member_type = member_type
-            enum_member._name = member_name
+                original_value = member_type(*args)
+            if not hasattr(enum_member, '_value_'):
+                enum_member._value_ = original_value
+            value = enum_member._value_
+            enum_member._member_type_ = member_type
+            enum_member._name_ = member_name
             enum_member.__init__(*args)
             # If another member with the same value was already defined, the
             # new member becomes an alias to the existing one.
-            for name, canonical_member in enum_class._member_map.items():
-                if canonical_member.value == enum_member._value:
+            for name, canonical_member in enum_class._member_map_.items():
+                if canonical_member.value == enum_member._value_:
                     enum_member = canonical_member
                     break
             else:
                 # Aliases don't appear in member names (only in __members__).
-                enum_class._member_names.append(member_name)
-            enum_class._member_map[member_name] = enum_member
+                enum_class._member_names_.append(member_name)
+            enum_class._member_map_[member_name] = enum_member
             try:
                 # This may fail if value is not hashable. We can't add the value
                 # to the map, and by-value lookups for this value will be
                 # linear.
-                enum_class._value2member_map[value] = enum_member
+                enum_class._value2member_map_[value] = enum_member
             except TypeError:
                 pass
 
         # in Python2.x we cannot know definition order, so go with value order
         # unless __order__ was specified in the class definition
         if not order_specified:
-            enum_class._member_names = [
+            enum_class._member_names_ = [
                 e[0] for e in sorted(
-                [(name, enum_class._member_map[name]) for name in enum_class._member_names],
-                 key=lambda t: t[1]._value
+                [(name, enum_class._member_map_[name]) for name in enum_class._member_names_],
+                 key=lambda t: t[1]._value_
                         )]
 
         # double check that repr and friends are not the mixin's or various
@@ -296,10 +297,10 @@ class EnumMeta(type):
         return cls._create_(value, names, module=module, type=type)
 
     def __contains__(cls, member):
-        return isinstance(member, cls) and member.name in cls._member_map
+        return isinstance(member, cls) and member.name in cls._member_map_
 
     def __dir__(self):
-        return ['__class__', '__doc__', '__members__'] + self._member_names
+        return ['__class__', '__doc__', '__members__'] + self._member_names_
 
     @property
     def __members__(cls):
@@ -309,7 +310,7 @@ class EnumMeta(type):
         is a copy of the internal mapping.
 
         """
-        return cls._member_map.copy()
+        return cls._member_map_.copy()
 
     def __getattr__(cls, name):
         """Return the enum member matching `name`
@@ -323,18 +324,18 @@ class EnumMeta(type):
         if _is_dunder(name):
             raise AttributeError(name)
         try:
-            return cls._member_map[name]
+            return cls._member_map_[name]
         except KeyError:
             raise AttributeError(name)
 
     def __getitem__(cls, name):
-        return cls._member_map[name]
+        return cls._member_map_[name]
 
     def __iter__(cls):
-        return (cls._member_map[name] for name in cls._member_names)
+        return (cls._member_map_[name] for name in cls._member_names_)
 
     def __len__(cls):
-        return len(cls._member_names)
+        return len(cls._member_names_)
 
     def __repr__(cls):
         return "<enum %r>" % cls.__name__
@@ -411,7 +412,7 @@ class EnumMeta(type):
         for base in bases:
             if  (base is not Enum and
                     issubclass(base, Enum) and
-                    base._member_names):
+                    base._member_names_):
                 raise TypeError("Cannot extend enumerations")
         # base is now the last base in bases
         if not issubclass(base, Enum):
@@ -563,24 +564,26 @@ def __new__(cls, value):
         #return value
     # by-value search for a matching enum member
     # see if it's in the reverse mapping (for hashable values)
-    if value in cls._value2member_map:
-        return cls._value2member_map[value]
-    # not there, now do long search -- O(n) behavior
-    for member in cls._member_map.values():
-        if member.value == value:
-            return member
+    try:
+        if value in cls._value2member_map_:
+            return cls._value2member_map_[value]
+    except TypeError:
+        # not there, now do long search -- O(n) behavior
+        for member in cls._member_map_.values():
+            if member.value == value:
+                return member
     raise ValueError("%s is not a valid %s" % (value, cls.__name__))
 temp_enum_dict['__new__'] = __new__
 del __new__
 
 def __repr__(self):
     return "<%s.%s: %r>" % (
-            self.__class__.__name__, self._name, self._value)
+            self.__class__.__name__, self._name_, self._value_)
 temp_enum_dict['__repr__'] = __repr__
 del __repr__
 
 def __str__(self):
-    return "%s.%s" % (self.__class__.__name__, self._name)
+    return "%s.%s" % (self.__class__.__name__, self._name_)
 temp_enum_dict['__str__'] = __str__
 del __str__
 
@@ -642,12 +645,12 @@ temp_enum_dict['__ne__'] = __ne__
 del __ne__
 
 def __getnewargs__(self):
-    return (self._value, )
+    return (self._value_, )
 temp_enum_dict['__getnewargs__'] = __getnewargs__
 del __getnewargs__
 
 def __hash__(self):
-    return hash(self._name)
+    return hash(self._name_)
 temp_enum_dict['__hash__'] = __hash__
 del __hash__
 
@@ -660,13 +663,13 @@ del __hash__
 
 @_RouteClassAttributeToGetattr
 def name(self):
-    return self._name
+    return self._name_
 temp_enum_dict['name'] = name
 del name
 
 @_RouteClassAttributeToGetattr
 def value(self):
-    return self._value
+    return self._value_
 temp_enum_dict['value'] = value
 del value
 
