@@ -537,7 +537,7 @@ class TestEnum(unittest.TestCase):
             def question(self):
                 print(42)
         self.assertFalse(type(Why.question) is Why)
-        self.assertTrue(Why.question not in Why._member_names)
+        self.assertTrue(Why.question not in Why._member_names_)
         self.assertTrue(Why.question not in Why)
 
     def test_wrong_inheritance_order(self):
@@ -811,10 +811,10 @@ class TestEnum(unittest.TestCase):
             def __new__(cls):
                 value = len(cls.__members__) + 1
                 obj = object.__new__(cls)
-                obj._value = value
+                obj._value_ = value
                 return obj
             def __int__(self):
-                return int(self._value)
+                return int(self._value_)
         if pyver < 3.0:
             self.assertEqual(3, len(AutoNumber))
         else:
@@ -828,10 +828,10 @@ class TestEnum(unittest.TestCase):
             def __new__(cls):
                 value = len(cls.__members__) + 1
                 obj = object.__new__(cls)
-                obj._value = value
+                obj._value_ = value
                 return obj
             def __int__(self):
-                return int(self._value)
+                return int(self._value_)
         class Color(AutoNumber2):
             __order__ = 'red green blue'
             red = ()
@@ -847,7 +847,7 @@ class TestEnum(unittest.TestCase):
             def __new__(cls):
                 value = len(cls.__members__) + 1
                 obj = int.__new__(cls, value)
-                obj._value = value
+                obj._value_ = value
                 return obj
         class Color(AutoNumber3):
             red = ()
@@ -862,19 +862,19 @@ class TestEnum(unittest.TestCase):
         class OrderedEnum(Enum):
             def __ge__(self, other):
                 if self.__class__ is other.__class__:
-                    return self._value >= other._value
+                    return self._value_ >= other._value_
                 return NotImplemented
             def __gt__(self, other):
                 if self.__class__ is other.__class__:
-                    return self._value > other._value
+                    return self._value_ > other._value_
                 return NotImplemented
             def __le__(self, other):
                 if self.__class__ is other.__class__:
-                    return self._value <= other._value
+                    return self._value_ <= other._value_
                 return NotImplemented
             def __lt__(self, other):
                 if self.__class__ is other.__class__:
-                    return self._value < other._value
+                    return self._value_ < other._value_
                 return NotImplemented
         class Grade(OrderedEnum):
             __order__ = 'A B C D F'
@@ -961,6 +961,22 @@ class TestEnum(unittest.TestCase):
         self.assertEqual(round(Planet.EARTH.surface_gravity, 2), 9.80)
         self.assertEqual(Planet.EARTH.value, (5.976e+24, 6.37814e6))
 
+    def test_nonhash_value(self):
+        class AutoNumberInAList(Enum):
+            def __new__(cls):
+                value = [len(cls.__members__) + 1]
+                obj = object.__new__(cls)
+                obj._value_ = value
+                return obj
+        class ColorInAList(AutoNumberInAList):
+            __order__ = 'red green blue'
+            red = ()
+            green = ()
+            blue = ()
+        self.assertEqual(list(ColorInAList), [ColorInAList.red, ColorInAList.green, ColorInAList.blue])
+        self.assertEqual(ColorInAList.red.value, [1])
+        self.assertEqual(ColorInAList([1]), ColorInAList.red)
+
 
 class TestUnique(unittest.TestCase):
     """2.4 doesn't allow class decorators, use function syntax."""
